#!/bin/sh
#
ME=$(readlink -f "$0")
MEDIR=${ME%/*}

PATHMIN=${PWD%.*}
MINOR=${PATHMIN##*.}

EXT=postgresql-9.$MINOR
PGDIR=pgsql9$MINOR

. $MEDIR/phase-default-init.sh

DEPS="openssl-dev libxml2-dev libxslt-dev gettext perl5 python-dev python tzdata tcl8.6-dev tcl8.6"

. $MEDIR/phase-default-deps.sh
. $MEDIR/phase-default-cc-opts.sh

for a in $(grep -l -r 'define NAMEDATALEN' *); do
	sed -i -e 's/define NAMEDATALEN .*$/define NAMEDATALEN 128/' $a
done

./configure \
	--prefix=/usr/local/$PGDIR \
	--localstatedir=/var \
	--disable-rpath \
	--with-openssl \
	--with-uuid=e2fs \
	--with-libxml \
	--with-libxslt \
	--with-perl \
	--with-python \
	--with-tcl \
	--enable-nls \
	--with-system-tzdata=/usr/local/share/zoneinfo \
	|| exit

. $MEDIR/phase-default-make.sh
. $MEDIR/phase-default-make-install.sh

cd contrib && make && make install DESTDIR=$TCZ && cd .. || exit

mkdir -p $TCZ-dev/usr/local/$PGDIR/bin
mkdir -p $TCZ-dev/usr/local/$PGDIR/lib
mkdir -p $TCZ-client/usr/local/$PGDIR/bin
mkdir -p $TCZ-client/usr/local/$PGDIR/lib

mv $TCZ/usr/local/$PGDIR/include $TCZ-dev/usr/local/$PGDIR
mv $TCZ/usr/local/$PGDIR/lib/pgxs $TCZ-dev/usr/local/$PGDIR/lib
mv $TCZ/usr/local/$PGDIR/lib/pkgconfig $TCZ-dev/usr/local/$PGDIR/lib
mv $TCZ/usr/local/$PGDIR/lib/*.a $TCZ-dev/usr/local/$PGDIR/lib
cp -a $TCZ/usr/local/$PGDIR/lib $TCZ-dev/usr/local/$PGDIR
mv $TCZ/usr/local/$PGDIR/bin/pg_config $TCZ-dev/usr/local/$PGDIR/bin

cp $TCZ/usr/local/$PGDIR/bin/psql $TCZ-client/usr/local/$PGDIR/bin
cp -a $TCZ/usr/local/$PGDIR/lib/libpq.so* $TCZ-client/usr/local/$PGDIR/lib

. $MEDIR/phase-default-strip.sh
. $MEDIR/phase-default-set-perms.sh
. $MEDIR/phase-default-squash-tcz.sh

